@@ -7,6 +7,7 @@ import click
 import osxphotos
 from osxphotos.cli.click_rich_echo import (
     rich_click_echo,
+    rich_echo_error,
     set_rich_console,
     set_rich_theme,
 )
@@ -40,8 +41,7 @@ MACOS_OPTIONS = make_click_option_decorator(
             metavar="ALBUM",
             help="Add all photos from query to album ALBUM in Photos. Album ALBUM will be created "
             "if it doesn't exist.  All photos in the query results will be added to this album. "
-            "This only works if the Photos library being queried is the last-opened (default) library in Photos. "
-            "This feature is currently experimental.  I don't know how well it will work on large query sets.",
+            "This only works if the Photos library being queried is the last-opened (default) library in Photos. ",
         ),
     ]
     if is_macos
@@ -76,7 +76,9 @@ MACOS_OPTIONS = make_click_option_decorator(
     "Most useful with --quiet. "
     "May be repeated to print multiple template strings. ",
 )
-@DB_ARGUMENT
+@click.option(
+    "--mute", is_flag=True, help="Mute status output while loading Photos library."
+)
 @click.pass_obj
 @click.pass_context
 def query(
@@ -88,7 +90,7 @@ def query(
     count,
     print_template,
     quiet,
-    photos_library,
+    mute,
     add_to_album=False,
     **kwargs,
 ):
@@ -113,7 +115,7 @@ def query(
 
     # below needed for to make CliRunner work for testing
     cli_db = cli_obj.db if cli_obj is not None else None
-    db = get_photos_db(*photos_library, db, cli_db)
+    db = get_photos_db(db, cli_db)
     if db is None:
         click.echo(ctx.obj.group.commands["query"].get_help(ctx), err=True)
         click.echo("\n\nLocated the following Photos library databases: ", err=True)
@@ -125,10 +127,11 @@ def query(
     except Exception as e:
         raise click.BadOptionUsage("query", str(e)) from e
 
+    verbose = None if mute else rich_echo_error
     photosdb = (
-        osxphotos.iPhotoDB(db)
+        osxphotos.iPhotoDB(db, verbose=verbose)
         if is_iphoto_library(db)
-        else osxphotos.PhotosDB(dbfile=db)
+        else osxphotos.PhotosDB(dbfile=db, verbose=verbose)
     )
 
     try:
